@@ -30,7 +30,14 @@ from pytest_bdd.types import SCENARIO, GIVEN, WHEN, THEN  # pragma: no cover
 
 class FeatureError(Exception):  # pragma: no cover
     """Feature parse error."""
-    pass
+
+    message = u'{0}.\nLine number: {1}.\nLine: {2}.'
+
+    def __str__(self):
+        return unicode(self).encode('utf-8')
+
+    def __unicode__(self):
+        return self.message.format(*self.args)
 
 
 # Global features dictionary
@@ -113,7 +120,7 @@ class Feature(object):
 
         with open(filename, 'r') as f:
             content = f.read()
-            for line in content.split('\n'):
+            for line_number, line in enumerate(content.split('\n')):
                 line = strip(line)
                 if not line:
                     continue
@@ -121,13 +128,16 @@ class Feature(object):
                 mode = get_step_type(line) or mode
 
                 if mode == GIVEN and prev_mode not in (GIVEN, SCENARIO):
-                    raise FeatureError('Given steps must be the first in withing the Scenario')
+                    raise FeatureError('Given steps must be the first in withing the Scenario',
+                                       line_number, line)
 
                 if mode == WHEN and prev_mode not in (SCENARIO, GIVEN, WHEN):
-                    raise FeatureError('When steps must be the first or follow Given steps')
+                    raise FeatureError('When steps must be the first or follow Given steps',
+                                       line_number, line)
 
                 if mode == THEN and prev_mode not in (GIVEN, WHEN, THEN):
-                    raise FeatureError('Then steps must follow Given or When steps')
+                    raise FeatureError('Then steps must follow Given or When steps',
+                                       line_number, line)
 
                 prev_mode = mode
 
@@ -137,7 +147,7 @@ class Feature(object):
                 if mode == SCENARIO:
                     self.scenarios[line] = scenario = Scenario(line)
                 else:
-                    scenario.add_step(line)
+                    scenario.add_step(step_name=line, step_type=mode)
 
     @classmethod
     def get_feature(cls, filename):
@@ -167,7 +177,20 @@ class Scenario(object):
         self.params = set()
         self.steps = []
 
-    def add_step(self, step):
-        """Add step."""
-        self.params.update(get_step_params(step))
-        self.steps.append(step)
+    def add_step(self, step_name, step_type):
+        """Add step to the scenario.
+
+        :param step_name: Step name.
+        :param step_type: Step type.
+
+        """
+        self.params.update(get_step_params(step_name))
+        self.steps.append(Step(name=step_name, type=step_type))
+
+
+class Step(object):
+    """Step."""
+
+    def __init__(self, name, type):
+        self.name = name
+        self.type = type
